..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Key Terms
---------

.. table::

    ========================== ============================ ========================
    abstract data type (ADT)   formatted strings            override
    abstraction                Has-a relationship           procedural abstraction
    algorithm                  implementation-independent   programming
    class                      information hiding           prompt
    computable                 inheritance                  ``self``
    data abstraction           inheritance hierarchy        set
    data structure             interface                    shallow equality
    data type                  Is-a relationship            simulation
    deep equality              list                         string
    dictionary                 list comprehension           subclass
    encapsulation              method                       superclass
    exception                  mutability                   truth table
    f-string                   object                       tuple
    format operator
    ========================== ============================ ========================



